@@ -1,18 +1,9 @@
 from .sdk import serverlessSdk
+from .api_events import is_api_event
 
 aws_lambda_span = serverlessSdk.trace_spans.aws_lambda
 
 
-def is_api_event():
-    return aws_lambda_span.tags.get("aws.lambda.event_type") in [
-        "aws.apigateway.rest",
-        "aws.apigatewayv2.http.v1",
-        "aws.apigatewayv2.http.v2",
-        "aws.lambda.url",
-        "aws.elasticloadbalancing.http",
-    ]
-
-
 def resolve(response):
     if not is_api_event():
         return
